{% extends "layout.html" %}
{% block body %}
<h1>502 - High load</h1>
<p>We are experiencing a high load of traffic.  For urgent matters,
  please contact <a href="mailto:{{email}}">our support team</a>.</p>
{% endblock %}
