{% extends "layout.html" %}
{% block body %}
<h1>500 - Oops</h1>
<p>We encountered an unexpected condition on the server-side.  For urgent matters,
  please contact <a href="mailto:{{email}}">our support team</a>.</p>
{% endblock %}
